==> xircuits-1.9.5.tar.gz: xircuits-1.9.5/xai_components/readme.md <==
# Xircuits Component Library List

## Internal Library

These components will always be included in the Xircuits installation.

<div align="center">

| Name     | Description                                                                                    | Link |
| -------- | ---------------------------------------------------------------------------------------------- | ---- |
| Controlflow | Components to enable ifs and loops. | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_controlflow) |
| Template | Great components for new learners and to experiment outputs.                                   | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_template) |
| Utils    | Commonly used components for day-to-day workflows.                                             | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_utils) |


</div>


## External Library

Recognized additional component libraries that you can download and install using:

```
$ xircuits install <component library name>
```

<div align="center">

### 📊 Data Science, Machine Learning, and Data Processing
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Tensorflow Keras](https://github.com/XpressAI/xai-tensorflow-keras) | Harness the full potential of deep learning with TensorFlow Keras components for intuitive model building and training. | - |
| [Pytorch](https://github.com/XpressAI/xai-pytorch) | Dive into deep learning with PyTorch's dynamic computation and advanced neural network components. | - |
| [SKlearn](https://github.com/XpressAI/xai-sklearn) | Empower your machine learning projects with Scikit-learn's versatile algorithms and data processing components. | - |
| [XGBoost](https://github.com/XpressAI/xai-xgboost) | Boost your models' performance with XGBoost's scalable and efficient gradient boosting components. | - |
| [Spark](https://github.com/XpressAI/xai-spark)    | Scale your data processing and machine learning tasks with Spark's high-performance components. | - |
| [Pycaret](https://github.com/XpressAI/xai-pycaret) | Simplify your ML workflow with PyCaret's comprehensive and easy-to-use machine learning components. | 0.1.0 |
| [RPA](https://github.com/yuenherny/xai-rpa) | Automate your routine tasks effortlessly with robust Robotic Process Automation components. | 0.2.1 |
| [Streamlit](https://github.com/XpressAI/xai-streamlit) | Transform your ML models into interactive web apps with Streamlit's seamless integration. | 0.1.0 |

### 🤖 AI Agents
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GPT Agent Toolkit](https://github.com/XpressAI/xai-gpt-agent-toolkit) | Experiment with and create Collaborative Large Language Model-based automatons (Agents) in the style of BabyAGI and Auto-GPT. | 0.1.0 |
| [Vecto](https://github.com/XpressAI/xai-vecto) | The power of vector embeddings in Xircuits. | 0.1.0 |
| [OpenAI](https://github.com/XpressAI/xai-openai) | Easily integrate OpenAI's functionalities, such as retrieving models and generating text, into your Xircuits projects! | 0.1.0 |
| [Anthropic](https://github.com/XpressAI/xai-anthropic) | Advanced components for anthropic principles. | - |
| [HF Agent](https://github.com/XpressAI/xai-hfagent) | Advanced components for hugging face agents. | - |
| [Actors](https://github.com/XpressAI/xai-actors) | Components for creating actor models. | - |
| [VertexAI](https://github.com/XpressAI/xai-google-vertexai) | Components that interfaces with Google Vertex AI! | - |

### 💬 Communication
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Slack](https://github.com/XpressAI/xai-slack) | Xircuits Component Library to interface with Slack! | 0.1.0 |
| [Discord](https://github.com/XpressAI/xai-discord) | Create Discord Bots in seconds. | 0.1.0 |

### 📭 Message Queues
| Name | Description | Version |
| ---- | ----------- | ------- |
| [RabbitMQ](https://github.com/XpressAI/xai-rabbitmq) | Message broker in Xircuits that just works. | 0.1.0 |
| [MQTT](https://github.com/XpressAI/xai-mqtt) | Xircuits library that implements the standard for IoT Messaging. | 0.1.0 |

### 🗃 Databases & Servers
| Name | Description | Version |
| ---- | ----------- | ------- |
| [SQLite](https://github.com/XpressAI/xai-sqlite) | Components for interfacing with SQLite databases. | - |
| [Flask](https://github.com/XpressAI/xai-flask) | Components for developing Flask applications. | - |

### 🌍 Cloud Services
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GDrive](https://github.com/XpressAI/xai-gdrive) | Components for interacting with Google Drive. | - |
| [GSpread](https://github.com/XpressAI/xai-gspread) | Components for interfacing with Google Sheets. | - |

</div>

Want your component library listed here? Just submit a PR to the Xircuits repository. For more information, refer to the [Xircuits component library documentation](https://xircuits.io/docs/component-library/).

==> xircuits-1.10.5.tar.gz: xircuits-1.10.5/xai_components/readme.md <==
# Xircuits Component Library List

## Internal Library

These components will always be included in the Xircuits installation.

<div align="center">

| Name     | Description                                                                                    | Link |
| -------- | ---------------------------------------------------------------------------------------------- | ---- |
| Controlflow | Components to enable ifs and loops. | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_controlflow) |
| Template | Great components for new learners and to experiment outputs.                                   | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_template) |
| Utils    | Commonly used components for day-to-day workflows.                                             | [Link](https://github.com/XpressAI/xircuits/tree/master/xai_components/xai_utils) |


</div>


## External Library

Recognized additional component libraries that you can download and install using:

```
$ xircuits install <component library name>
```

<div align="center">

### 📊 Data Science, Machine Learning, and Data Processing
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Tensorflow Keras](https://github.com/XpressAI/xai-tensorflow-keras) | Harness the full potential of deep learning with TensorFlow Keras components for intuitive model building and training. | - |
| [Pytorch](https://github.com/XpressAI/xai-pytorch) | Dive into deep learning with PyTorch's dynamic computation and advanced neural network components. | - |
| [SKlearn](https://github.com/XpressAI/xai-sklearn) | Empower your machine learning projects with Scikit-learn's versatile algorithms and data processing components. | - |
| [XGBoost](https://github.com/XpressAI/xai-xgboost) | Boost your models' performance with XGBoost's scalable and efficient gradient boosting components. | - |
| [Spark](https://github.com/XpressAI/xai-spark)    | Scale your data processing and machine learning tasks with Spark's high-performance components. | - |
| [Pycaret](https://github.com/XpressAI/xai-pycaret) | Simplify your ML workflow with PyCaret's comprehensive and easy-to-use machine learning components. | 0.1.0 |
| [RPA](https://github.com/yuenherny/xai-rpa) | Automate your routine tasks effortlessly with robust Robotic Process Automation components. | 0.2.1 |
| [Streamlit](https://github.com/XpressAI/xai-streamlit) | Transform your ML models into interactive web apps with Streamlit's seamless integration. | 0.1.0 |

### 🤖 AI Agents
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GPT Agent Toolkit](https://github.com/XpressAI/xai-gpt-agent-toolkit) | Experiment with CLM-based automatons in BabyAGI and Auto-GPT style. | 0.1.0 |
| [Vecto](https://github.com/XpressAI/xai-vecto) | Leverage vector embeddings in Xircuits. | 0.1.0 |
| [OpenAI](https://github.com/XpressAI/xai-openai) | Integrate OpenAI models and text generation into Xircuits. | 0.1.0 |
| [Anthropic](https://github.com/XpressAI/xai-anthropic) | Advanced anthropic principle components. | - |
| [HF Agent](https://github.com/XpressAI/xai-hfagent) | Components for Hugging Face agents. | - |
| [Actors](https://github.com/XpressAI/xai-actors) | Create actor models in Xircuits. | - |
| [VertexAI](https://github.com/XpressAI/xai-google-vertexai) | Interface with Google Vertex AI in Xircuits. | - |
| [Xircuits Converse](https://github.com/XpressAI/xai-converse) | Integrate conversational AI with OpenAI API in Xircuits. | - |
| [Xpress AI Agent Library](https://github.com/XpressAI/xai-agent) | Define agents and tools in Xircuits with OpenAI and Google Vertex support. | - |
| [Stability AI](https://github.com/YourGithubRepo/xai-stabilityai) | Generate, modify, and upscale images using Stability AI components. | 0.1.0 |


### 💬 Communication
| Name | Description | Version |
| ---- | ----------- | ------- |
| [Slack](https://github.com/XpressAI/xai-slack) | Xircuits Component Library to interface with Slack! | 0.1.0 |
| [Discord](https://github.com/XpressAI/xai-discord) | Create Discord Bots in seconds. | 0.1.0 |

### 📭 Message Queues
| Name | Description | Version |
| ---- | ----------- | ------- |
| [RabbitMQ](https://github.com/XpressAI/xai-rabbitmq) | Message broker in Xircuits that just works. | 0.1.0 |
| [MQTT](https://github.com/XpressAI/xai-mqtt) | Xircuits library that implements the standard for IoT Messaging. | 0.1.0 |

### 🗃 Databases & Servers
| Name | Description | Version |
| ---- | ----------- | ------- |
| [SQLite](https://github.com/XpressAI/xai-sqlite) | Components for interfacing with SQLite databases. | - |
| [Flask](https://github.com/XpressAI/xai-flask) | Components for developing Flask applications. | - |

### 🌍 Cloud Services
| Name | Description | Version |
| ---- | ----------- | ------- |
| [GDrive](https://github.com/XpressAI/xai-gdrive) | Components for interacting with Google Drive. | - |
| [GSpread](https://github.com/XpressAI/xai-gspread) | Components for interfacing with Google Sheets. | - |

</div>

Want your component library listed here? Just submit a PR to the Xircuits repository. For more information, refer to the [Xircuits component library documentation](https://xircuits.io/docs/component-library/).
